@@ -1,8 +1,18 @@
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Tests for the import manager. """
 
+import unittest
 
 from traits.util.api import import_symbol
-from traits.testing.unittest_tools import unittest
 
 
 class TestImportSymbol(unittest.TestCase):
@@ -16,8 +26,6 @@ class TestImportSymbol(unittest.TestCase):
         symbol = import_symbol("tarfile.TarFile")
         self.assertEqual(symbol, tarfile.TarFile)
 
-        return
-
     def test_import_nested_symbol(self):
         """ import nested symbol """
 
@@ -26,19 +34,9 @@ class TestImportSymbol(unittest.TestCase):
         symbol = import_symbol("tarfile:TarFile.open")
         self.assertEqual(symbol, tarfile.TarFile.open)
 
-        return
-
     def test_import_dotted_module(self):
         """ import dotted module """
 
         symbol = import_symbol("traits.util.import_symbol:import_symbol")
 
         self.assertEqual(symbol, import_symbol)
-
-        return
-
-
-if __name__ == "__main__":
-    unittest.main()
-
-#### EOF ######################################################################
